[ 
https://issues.apache.org/jira/browse/HIVE-13887?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel&focusedCommentId=15681553#comment-15681553
 ] 

Sergio Peña commented on HIVE-13887:
------------------------------------

I'm moving this JIRA out of 2.1.1 release as it is not a blocker nor critical 
for a 2.1.1 RC version. Feel free to commit it to branch 2.1 if the patch is 
ready before the release.

> LazySimpleSerDe should parse "NULL" dates faster
> ------------------------------------------------
>
>                 Key: HIVE-13887
>                 URL: https://issues.apache.org/jira/browse/HIVE-13887
>             Project: Hive
>          Issue Type: Bug
>          Components: Serializers/Deserializers, Vectorization
>    Affects Versions: 2.1.0
>            Reporter: Gopal V
>            Assignee: Gopal V
>              Labels: Performance
>             Fix For: 2.2.0
>
>         Attachments: HIVE-13887.1.patch, HIVE-13887.1.patch
>
>
> Date string which contain "NULL" or "(null)" are being parsed through a very 
> slow codepath involving exception handling as a normal codepath.
> These are currently ~4x slower than parsing an actual date field.



--
This message was sent by Atlassian JIRA
(v6.3.4#6332)

Reply via email to